Index: /branches/master/array-ingress/task-manager/openshift/apv/const.go
===================================================================
--- /branches/master/array-ingress/task-manager/openshift/apv/const.go	(revision 21)
+++ /branches/master/array-ingress/task-manager/openshift/apv/const.go	(working copy)
@@ -45,13 +45,9 @@
 
 // Function map to handle different task/resource combinations
 var apvFunctionMap = map[string]SetUpFunc{
-	"ROUTE_ADD":    handleRouteAdd,
-	"ROUTE_UPDATE": handleRouteUpdate,
-	"ROUTE_DELETE": handleRouteDelete,
-	"ENDPOINT_ADD": handleEndpointAdd,
-	//"ENDPOINT_UPDATE": handleEndpointUpdate,
+	"ROUTE_ADD":       handleRouteAdd,
+	"ROUTE_UPDATE":    handleRouteUpdate,
+	"ROUTE_DELETE":    handleRouteDelete,
+	"ENDPOINT_ADD":    handleEndpointAdd,
 	"ENDPOINT_DELETE": handleEndpointDelete,
-	//"POD_ADD":        handlePodAdd,
-	//"POD_DELETE":     handlePodDelete,
-	//"SERVICE_UPDATE": handleServiceUpdate,
 }
Index: /branches/master/array-ingress/task-manager/openshift/apv/health.go
===================================================================
--- /branches/master/array-ingress/task-manager/openshift/apv/health.go	(revision 21)
+++ /branches/master/array-ingress/task-manager/openshift/apv/health.go	(working copy)
@@ -1,5 +1,11 @@
 /*
 	Copyright 2025 Array Networks
+
+	This file manages the controller-side operations related to HealthCheck
+    functionalities.It includes functions to add, update, and delete health check configurations in db
+    based on route annotations. Here we are just marking the rows in with intended Status and Operation
+	for a specific healthcheck in different scenarios. Actual CRUD is performed in APV Adapter module.
+
 */
 
 package apv
@@ -13,6 +19,8 @@
 	taskManager "arraynetworks.com/array-ingress-controller/task-manager/task"
 )
 
+// healthCheckAnnotStruct defines the structure for health check annotations
+// in the route. These fields are used to configure health checks for services.
 type healthCheckAnnotStruct struct {
 	Path         *string `json:"path,omitempty"`
 	Type         *string `json:"hc_type,omitempty"`
@@ -23,14 +31,19 @@
 	Retries      *int    `json:"retries,omitempty"`
 }
 
+// addHealthCheck adds a health check configuration to the config store
+// based on the annotation present on the route. It initializes new health check
+// records for each real service associated with the route.
 func addHealthCheck(task *taskManager.Task) error {
 
+	// Initialize the configstore
 	configStore, err := configstore.Get()
 	if err != nil {
 		log.Errorf("Error initializing config store: %v", err)
 		return err
 	}
 
+	// Fetch JSON string from route annotations
 	annots, _ := utils.FetchJSONStringFromAnnotation(task.Route[0], HealthCheckAnnotKey)
 
 	// Unmarshal the JSON string into a HealthCheck struct
@@ -89,6 +102,8 @@
 	return nil
 }
 
+// updateHealthCheck updates existing health check configurations in the config store
+// based on the annotation changes in the route.
 func updateHealthCheck(task *taskManager.Task) error {
 
 	configStore, err := configstore.Get()
@@ -119,7 +134,6 @@
 
 	// Set status to delete for each service record
 	for _, realService := range realServices {
-		// TODO: Update only the fields which are changed
 		healthCheck := configstore.HealthCheck{
 			IngressName:   realService.IngressName,
 			HCName:        "hc" + realService.ServiceName,
@@ -153,6 +167,8 @@
 
 }
 
+// deleteHealthCheck deletes health check configurations from the config store
+// by marking them for deletion based on the route.
 func deleteHealthCheck(task *taskManager.Task) error {
 
 	// Initialize the config store
Index: /branches/master/array-ingress/task-manager/openshift/apv/ratelimit.go
===================================================================
--- /branches/master/array-ingress/task-manager/openshift/apv/ratelimit.go	(revision 21)
+++ /branches/master/array-ingress/task-manager/openshift/apv/ratelimit.go	(working copy)
@@ -1,5 +1,12 @@
 /*
+
 	Copyright 2025 Array Networks
+
+	This file manages the controller-side operations related to RateLimit
+    functionalities.It includes functions to add, update, and delete ratelimit configurations in db
+    based on route annotations. Here we are just marking the rows in with intended Status and Operation
+	for a specific healthcheck in different scenarios. Actual CRUD is performed in APV Adapter module.
+
 */
 
 package apv
@@ -13,6 +20,8 @@
 	taskManager "arraynetworks.com/array-ingress-controller/task-manager/task"
 )
 
+// rateLimitAnnotStruct defines the structure for health check annotations
+// in the route. These fields are used to configure health checks for services.
 type RateLimitAnnotStruct struct {
 	MaxCPS               *int    `json:"max_cps,omitempty"`
 	SoftBW               *int    `json:"soft_bandwidth,omitempty"`
@@ -24,6 +33,9 @@
 	ServerPersistentConn *bool   `json:"server_persistent_conn,omitempty"`
 }
 
+// addRateLimit adds a ratelimit configuration to the config store
+// based on the annotation present on the route. It initializes new ratelimit
+// records for each real service associated with the route.
 func addRateLimit(task *taskManager.Task) error {
 	configStore, err := configstore.Get()
 	if err != nil {
@@ -39,6 +51,8 @@
 	if err != nil {
 		return fmt.Errorf("Error unmarshaling JSON from annotation: %v", err)
 	}
+
+	// check if endpoint is not nil
 	if task.EndPts == nil || len(task.EndPts) == 0 || task.EndPts[0].Subsets == nil {
 		log.Warnf("No endpoint subsets found for route %s", task.Route[0].Name)
 		return nil
@@ -87,6 +101,8 @@
 	return nil
 }
 
+// updateAddRateLimit updates existing ratelimit configurations in the config store
+// based on the annotation changes in the route.
 func updateAddRateLimit(task *taskManager.Task) error {
 
 	configStore, err := configstore.Get()
@@ -151,6 +167,9 @@
 
 }
 
+// updateDeleteRateLimit updates existing ratelimit configurations in the config store
+// based on the annotation changes in the route. Ratelimit is not deleted here, instead it
+// is updated with default values.
 func updateDeleteRateLimit(task *taskManager.Task) error {
 	configStore, err := configstore.Get()
 	if err != nil {
@@ -197,6 +216,8 @@
 	return nil
 }
 
+// deleteHealthCheck deletes ratelimit configurations from the config store
+// by marking them for deletion based on the route.
 func deleteRateLimit(task *taskManager.Task) error {
 	// Initialize the config store
 	configStore, err := configstore.Get()
@@ -205,6 +226,7 @@
 		return err
 	}
 
+	// check if endpoint is not nil
 	if task.EndPts == nil || len(task.EndPts) == 0 || task.EndPts[0].Subsets == nil {
 		log.Warnf("No endpoint subsets found for route %s", task.Route[0].Name)
 		return nil
@@ -258,6 +280,8 @@
 	return nil
 }
 
+// deleteEndpointRateLimit deletes ratelimit configurations from the config store
+// by marking them for deletion based on the route.
 func deleteEndpointRateLimit(task *taskManager.Task) error {
 	// Initialize the config store
 	configStore, err := configstore.Get()
@@ -265,6 +289,8 @@
 		log.Errorf("Error initializing Configstore: %v", err)
 		return err
 	}
+
+	// check if endpoint is not nil
 	if task.EndPts == nil || len(task.EndPts) == 0 || task.EndPts[0].Subsets == nil {
 		log.Warnf("No endpoint subsets found for route %s", task.Route[0].Name)
 		return nil
Index: /branches/master/array-ingress/task-manager/openshift/apv/realservice.go
===================================================================
--- /branches/master/array-ingress/task-manager/openshift/apv/realservice.go	(revision 21)
+++ /branches/master/array-ingress/task-manager/openshift/apv/realservice.go	(working copy)
@@ -1,3 +1,14 @@
+/*
+
+	Copyright 2025 Array Networks
+
+	This file manages the controller-side operations related to RealService
+    functionalities.It includes functions to add, update, and delete realservice configurations in db
+    based on route. Here we are just marking the rows in with intended Status and Operation
+	for a specific healthcheck in different scenarios. Actual CRUD is performed in APV Adapter module.
+
+*/
+
 package apv
 
 import (
@@ -8,6 +19,9 @@
 	taskManager "arraynetworks.com/array-ingress-controller/task-manager/task"
 )
 
+// addRealService adds a realservice configuration to the config store
+// based on the annotation present on the route. It initializes new realservice
+// records for each real service associated with the route.
 func addRealService(task *taskManager.Task) error {
 	log.Info("Handling Route Add with additional context data")
 
@@ -17,6 +31,7 @@
 		log.Error("Error initializing config store: %v", err)
 		return err
 	}
+	// check if endpoint is not nil
 	if task.EndPts == nil || len(task.EndPts) == 0 || task.EndPts[0].Subsets == nil {
 		log.Warnf("No endpoint subsets found for route %s", task.Route[0].Name)
 		return nil
@@ -64,6 +79,7 @@
 	return nil
 }
 
+// deleteRealService deletes existing realservice configurations in the config store.
 func deleteRealService(task *taskManager.Task) error {
 
 	// Initialize the config store
@@ -129,6 +145,8 @@
 	return nil
 }
 
+// updateRealService updates existing realservice configurations in the config store
+// based on the changes in route spec
 func updateRealService(task *taskManager.Task) error {
 
 	// Initialize the config store
Index: /branches/master/array-ingress/task-manager/openshift/asf/asf.go
===================================================================
--- /branches/master/array-ingress/task-manager/openshift/asf/asf.go	(revision 21)
+++ /branches/master/array-ingress/task-manager/openshift/asf/asf.go	(working copy)
@@ -1,5 +1,13 @@
 /*
 	Copyright 2025 Array Networks
+
+	This file contains the implementation of the OpenShiftASF struct, which provides
+    handler functions to manage routes and endpoints within OpenShift
+    environments, including adding, updating, and deleting routes and endpoints.
+
+	The handlers perform specific actions such as creating, updating, or deleting
+    real services, health checks, and rate limits based on annotations on routes.
+
 */
 
 package asf
@@ -13,11 +21,16 @@
 	routev1 "github.com/openshift/api/route/v1"
 )
 
+// SetUpFunc is a type definition for functions that perform setup tasks.
 type SetUpFunc func(ctx context.Context, task *taskManager.Task) error
 
-// OpenShiftASF implements the ASFHandler interface for OpenShift
+// OpenShiftASF implements the APVHandler interface for OpenShift.
+// This struct manages the setup and execution of ASF-related tasks
+// within the OpenShift environment.
 type OpenShiftASF struct{}
 
+// SetupASF sets up ASF-specific tasks based on the context and task provided.
+// It uses a map of handler functions to perform actions based on task and resource types.
 func (o *OpenShiftASF) SetupASF(ctx context.Context, task *taskManager.Task) error {
 	// OpenShift-specific ASF setup logic
 	log.Info("Setting up ASF on OpenShift")
@@ -40,7 +53,8 @@
 	return nil
 }
 
-// Implementations of task handlers
+// handleRouteAdd manages the addition of routes, including creating real services,
+// health checks, and rate limits based on annotations present.
 func handleRouteAdd(ctx context.Context, task *taskManager.Task) error {
 	log.Info("Handling Route Add with additional context data")
 	var err error
@@ -60,6 +74,8 @@
 	return nil
 }
 
+// handleRouteUpdate manages the updating of routes, including updating real services,
+// health checks, and rate limits based on annotations present and context values.
 func handleRouteUpdate(ctx context.Context, task *taskManager.Task) error {
 	// Creating a context with a value
 	value, _ := ctx.Value("spec_updated").(string)
@@ -94,6 +110,8 @@
 	return nil
 }
 
+// handleRouteDelete manages the deletion of routes, including creating real services,
+// health checks, and rate limits based on annotations present.
 func handleRouteDelete(ctx context.Context, task *taskManager.Task) error {
 	log.Info("Handling Route Delete with additional context data")
 
@@ -113,7 +131,8 @@
 	return nil
 }
 
-// Endpoint functions
+// handleEndpointAdd manages the addition of endpoints, including creating real services,
+// health checks, and rate limits based on annotations present.
 func handleEndpointAdd(ctx context.Context, task *taskManager.Task) error {
 	for _, route := range task.Route {
 		var err error
@@ -136,6 +155,8 @@
 	return nil
 }
 
+// handleEndpointDelete manages the deletion of endpoints, including creating real services,
+// health checks, and rate limits based on annotations present.
 func handleEndpointDelete(ctx context.Context, task *taskManager.Task) error {
 	for _, route := range task.Route {
 		var err error
Index: /branches/master/array-ingress/task-manager/openshift/asf/const.go
===================================================================
--- /branches/master/array-ingress/task-manager/openshift/asf/const.go	(revision 21)
+++ /branches/master/array-ingress/task-manager/openshift/asf/const.go	(working copy)
@@ -28,13 +28,9 @@
 
 // Function map to handle different task/resource combinations
 var asfFunctionMap = map[string]SetUpFunc{
-	"ROUTE_ADD":    handleRouteAdd,
-	"ROUTE_UPDATE": handleRouteUpdate,
-	"ROUTE_DELETE": handleRouteDelete,
-	// TODO: Uncomment once pod handlers are ready.
-	// "POD_ADD":        handlePodAdd,
-	// "POD_DELETE":     handlePodDelete,
-	// "SERVICE_UPDATE": handleServiceUpdate,
+	"ROUTE_ADD":       handleRouteAdd,
+	"ROUTE_UPDATE":    handleRouteUpdate,
+	"ROUTE_DELETE":    handleRouteDelete,
 	"ENDPOINT_ADD":    handleEndpointAdd,
 	"ENDPOINT_DELETE": handleEndpointDelete,
 }
Index: /branches/master/array-ingress/task-manager/openshift/asf/health.go
===================================================================
--- /branches/master/array-ingress/task-manager/openshift/asf/health.go	(revision 21)
+++ /branches/master/array-ingress/task-manager/openshift/asf/health.go	(working copy)
@@ -1,5 +1,11 @@
 /*
 	Copyright 2025 Array Networks
+
+	This file manages the controller-side operations related to HealthCheck
+    functionalities.It includes functions to add, update, and delete health check configurations in db
+    based on route annotations. Here we are just marking the rows in with intended Status and Operation
+	for a specific healthcheck in different scenarios. Actual CRUD is performed in ASF Adapter module.
+
 */
 
 package asf
@@ -19,6 +25,9 @@
 	HCDown    *int    `json:"hc_down,omitempty"`
 }
 
+// addHealthCheck adds a health check configuration to the config store
+// based on the annotation present on the route. It initializes new health check
+// records for each real service associated with the route.
 func addHealthCheck(task *taskManager.Task) error {
 	configStore, err := configstore.Get()
 	if err != nil {
@@ -34,6 +43,7 @@
 	if err != nil {
 		return fmt.Errorf("error unmarshaling JSON from annotation: %v", err)
 	}
+	// check if endpoint is nil
 	if task.EndPts == nil || len(task.EndPts) == 0 || task.EndPts[0].Subsets == nil {
 		log.Warnf("No endpoint subsets found for route %s", task.Route[0].Name)
 		return nil
@@ -197,6 +207,8 @@
 	return nil
 }
 
+// deleteHealthCheck deletes health check configurations from the config store
+// by marking them for deletion based on the route.
 func deleteHealthCheck(task *taskManager.Task) error {
 	// Initialize the config store
 	configStore, err := configstore.Get()
Index: /branches/master/array-ingress/task-manager/openshift/asf/realservice.go
===================================================================
--- /branches/master/array-ingress/task-manager/openshift/asf/realservice.go	(revision 21)
+++ /branches/master/array-ingress/task-manager/openshift/asf/realservice.go	(working copy)
@@ -1,3 +1,14 @@
+/*
+
+	Copyright 2025 Array Networks
+
+	This file manages the controller-side operations related to RealService
+    functionalities.It includes functions to add, update, and delete realservice configurations in db
+    based on route. Here we are just marking the rows in with intended Status and Operation
+	for a specific healthcheck in different scenarios. Actual CRUD is performed in ASF Adapter module.
+
+*/
+
 package asf
 
 import (
@@ -9,6 +20,9 @@
 	taskManager "arraynetworks.com/array-ingress-controller/task-manager/task"
 )
 
+// addRealService adds a realservice configuration to the config store
+// based on the annotation present on the route. It initializes new realservice
+// records for each real service associated with the route.
 func addRealService(task *taskManager.Task) error {
 	log.Info("Handling Route Add with additional context data")
 
@@ -77,6 +91,7 @@
 	return nil
 }
 
+// deleteRealService deletes existing realservice configurations in the config store.
 func deleteRealService(task *taskManager.Task) error {
 	// Initialize the config store
 	configStore, err := configstore.Get()
@@ -140,6 +155,8 @@
 	return nil
 }
 
+// updateRealService updates existing realservice configurations in the config store
+// based on the changes in route spec
 func updateRealService(task *taskManager.Task) error {
 	// Initialize the config store
 	configStore, err := configstore.Get()

Index: /branches/master/array-ingress/task-manager/openshift/apv/apv.go
===================================================================
--- /branches/master/array-ingress/task-manager/openshift/apv/apv.go	(revision 21)
+++ /branches/master/array-ingress/task-manager/openshift/apv/apv.go	(working copy)
@@ -1,5 +1,13 @@
 /*
 	Copyright 2025 Array Networks
+
+	This file contains the implementation of the OpenShiftAPV struct, which provides
+    handler functions to manage routes and endpoints within OpenShift
+    environments, including adding, updating, and deleting routes and endpoints.
+
+	The handlers perform specific actions such as creating, updating, or deleting
+    real services, health checks, and rate limits based on annotations on routes.
+
 */
 
 package apv
@@ -14,11 +22,16 @@
 	routev1 "github.com/openshift/api/route/v1"
 )
 
+// SetUpFunc is a type definition for functions that perform setup tasks.
 type SetUpFunc func(ctx context.Context, task *taskManager.Task) error
 
 // OpenShiftAPV implements the APVHandler interface for OpenShift
 type OpenShiftAPV struct{}
 
+// SetupAPV sets up APV-specific tasks based on the context and task provided.
+// It uses a map of handler functions to perform actions based on task and resource types.
 func (o *OpenShiftAPV) SetupAPV(ctx context.Context, task *taskManager.Task) error {
 	// OpenShift-specific APV setup logic
 	log.Info("Setting up APV on OpenShift")
@@ -37,20 +50,24 @@
 	return nil
 }
 
-// Implementations of task handlers
+// handleRouteAdd manages the addition of routes, including creating real services,
+// health checks, and rate limits based on annotations present.
 func handleRouteAdd(ctx context.Context, task *taskManager.Task) error {
 	log.Info("Handling Route Add with additional context data")
 
 	var err error
 
-	//Handle RealService Creation
+	// Handle RealService Creation
+	// This creation is a result of new route added in cluster
 	err = addRealService(task)
 	if err != nil {
 		return err
 	}
 
-	// Check if health check annotation exists
-	// If it does, add health check
+	// Create Health check for RealSerivce if annotation exists.
+	// This creation is required since we created Realservice above on route addtion.
+	// We can directly use 0th index of route as each route is managed separately by controller
+	// hence there will always be only one route in this case.
 	if utils.AnnotationExists(task.Route[0], HealthCheckAnnotKey) {
 		err = addHealthCheck(task)
 		if err != nil {
@@ -58,8 +75,10 @@
 		}
 	}
 
-	// Check if rate limit annotation exists
-	// If it does, add rate limit
+	// Create ratelimit for RealSerivce if annotation exists.
+	// This creation is required since we created Realservice above on route addtion.
+	// We can directly use 0th index of route as each route is managed separately by controller
+	// hence there will always be only one route in this case.
 	if utils.AnnotationExists(task.Route[0], RateLimitAnnotKey) {
 		err = addRateLimit(task)
 		if err != nil {
@@ -70,6 +89,8 @@
 	return nil
 }
 
+// handleRouteUpdate manages the updating of routes, including updating real services,
+// health checks, and rate limits based on annotations present and context values.
 func handleRouteUpdate(ctx context.Context, task *taskManager.Task) error {
 	var err error
 	// Creating a context with a value
@@ -86,16 +107,19 @@
 	health_check_updated, _ := ctx.Value("health_check_updated").(string)
 
 	if health_in_old == "True" && health_in_new == "False" {
+		// delete healthcheck since annotation is removed in updated route
 		err = deleteHealthCheck(task)
 		if err != nil {
 			return err
 		}
 	} else if health_in_old == "False" && health_in_new == "True" {
+		// add healthcheck since annotation is added in the route
 		err = addHealthCheck(task)
 		if err != nil {
 			return err
 		}
 	} else if health_check_updated == "True" {
+		// already present healthcheck annotation updated
 		err = updateHealthCheck(task)
 		if err != nil {
 			return err
@@ -109,16 +133,19 @@
 	ratelimit_updated, _ := ctx.Value("ratelimit_updated").(string)
 
 	if ratelimit_in_old == "True" && ratelimit_in_new == "False" {
+		// delete ratelimit since annotation is removed in updated route
 		err = updateDeleteRateLimit(task)
 		if err != nil {
 			return err
 		}
 	} else if ratelimit_in_old == "False" && ratelimit_in_new == "True" {
+		// add ratelimit since annotation is added in the route
 		err = updateAddRateLimit(task)
 		if err != nil {
 			return err
 		}
 	} else if ratelimit_updated == "True" {
+		// add ratelimit since annotation is added in the route
 		err = updateAddRateLimit(task)
 		if err != nil {
 			return err
@@ -130,6 +157,8 @@
 	return nil
 }
 
+// handleRouteDelete manages the deletion of routes, including creating real services,
+// health checks, and rate limits based on annotations present.
 func handleRouteDelete(ctx context.Context, task *taskManager.Task) error {
 	log.Info("Handling Route Delete with additional context data")
 	//Handle RealService Deletion
@@ -159,13 +188,12 @@
 	return nil
 }
 
-// Endpoint functions
+// handleEndpointAdd manages the addition of endpoints, including creating real services,
+// health checks, and rate limits based on annotations present.
 func handleEndpointAdd(ctx context.Context, task *taskManager.Task) error {
 
 	for _, route := range task.Route {
-
 		var err error
-
 		task.Route = []*routev1.Route{route}
 
 		//Handle RealService Creation
@@ -196,6 +224,8 @@
 	return nil
 }
 
+// handleEndpointDelete manages the deletion of endpoints, including creating real services,
+// health checks, and rate limits based on annotations present.
 func handleEndpointDelete(ctx context.Context, task *taskManager.Task) error {
 
 	for _, route := range task.Route {
@@ -14,11 +22,16 @@
 type SetUpFunc func(ctx context.Context, task *taskManager.Task) error
 
-// OpenShiftAPV implements the APVHandler interface for OpenShift
+// OpenShiftAPV implements the APVHandler interface for OpenShift.
+// This struct manages the setup and execution of APV-related tasks
+// within the OpenShift environment.
 type OpenShiftAPV struct{}
 